componenttools.copy_governed_component_subtree_from_offset_to
=============================================================

.. autofunction:: abjad.tools.componenttools.copy_governed_component_subtree_from_offset_to.copy_governed_component_subtree_from_offset_to
   :noindex:
